@@ -1,3 +1,4 @@
+import html
 import re
 
 import requests
@@ -19,9 +20,12 @@ class Mangadex(Site):
         title = {
             "id": title_id,
             "name": md_json["manga"]["title"],
+            "site": "mangadex",
             "cover_ext": cover_ext,
             "alt_names": md_json["manga"]["alt_names"],
-            "descriptions": md_json["manga"]["description"].split("\r\n\r\n"),
+            "descriptions": html.unescape(md_json["manga"]["description"]).split(
+                "\r\n\r\n"
+            ),
             "chapters": [
                 {
                     "id": str(chap_id),
@@ -50,6 +54,7 @@ class Mangadex(Site):
         chapter = {
             "id": chapter_id,
             "title_id": md_json["manga_id"],
+            "site": "mangadex",
             "name": md_json["title"],
             "pages": [f"{img_path}/{page}" for page in md_json["page_array"]],
             "groups": _extract_groups(md_json),
