@@ -14,7 +14,7 @@ from flask import (
 )
 
 from .conf import config
-from .decorators import ensure_session_version, require_login, toggle_has_read
+from .decorators import require_login, toggle_has_read
 from .persistence import (
     follow,
     get_followed_titles,
@@ -45,7 +45,6 @@ app.config.update(
 
 
 @app.route("/")
-@ensure_session_version
 def home_view():
     if session.get("user"):
         return redirect(url_for("follows_view"))
@@ -53,7 +52,6 @@ def home_view():
 
 
 @app.route("/following", methods=["GET"])
-@ensure_session_version
 @require_login
 def follows_view():
     titles = get_followed_titles(session["user"]["id"])
@@ -66,7 +64,6 @@ def follows_view():
 
 
 @app.route("/follow/<site>/<title_id>", methods=["POST"])
-@ensure_session_version
 @require_login
 def follow_view(site, title_id):
     follow(session["user"]["id"], site, title_id)
@@ -74,7 +71,6 @@ def follow_view(site, title_id):
 
 
 @app.route("/unfollow/<site>/<title_id>", methods=["POST"])
-@ensure_session_version
 @require_login
 def unfollow_view(site, title_id):
     unfollow(session["user"]["id"], site, title_id)
@@ -82,14 +78,12 @@ def unfollow_view(site, title_id):
 
 
 @app.route("/logout", methods=["POST"])
-@ensure_session_version
 def logout_view():
     session.pop("user")
     return redirect("/")
 
 
 @app.route("/auth", methods=["GET", "POST"])
-@ensure_session_version
 def auth_view():
     if session.get("user"):
         return redirect(url_for("home_view"))
@@ -173,7 +167,6 @@ def auth_view():
 
 
 @app.route("/m/<site>/<title_id>")
-@ensure_session_version
 @toggle_has_read
 def title_view(site, title_id):
     user = session.get("user", None)
@@ -196,7 +189,6 @@ def title_view(site, title_id):
 
 
 @app.route("/m/<site>/<title_id>/<chapter_id>")
-@ensure_session_version
 @toggle_has_read
 def chapter_view(site, title_id, chapter_id):
     chapter = load_chapter(site, title_id, chapter_id)
@@ -216,16 +208,20 @@ def chapter_view(site, title_id, chapter_id):
 
     # YIIIIKES
     title = load_title(site, title_id)
+    title["cover"] = title_cover(site, title_id, title["cover_ext"])
+    if site == "mangadex":
+        title["cover"] = url_for(
+            "proxy_view", b64_url=_encode_proxy_url(title["cover"])
+        )
     prev_chapter, next_chapter = get_prev_next_chapters(title, chapter)
     chapter["prev_chapter"] = prev_chapter
     chapter["next_chapter"] = next_chapter
 
     chapter["site"] = site
-    return render_template("chapter.html", **chapter)
+    return render_template("chapter.html", title=title, **chapter)
 
 
 @app.route("/search")
-@ensure_session_version
 def search_view():
     query = request.args.get("q", "").strip()
     results = {}
@@ -249,7 +245,7 @@ def proxy_view(b64_url):
         return "Nope", 400
     md_resp = requests.get(url)
     resp = make_response(md_resp.content, md_resp.status_code)
-    resp.headers.extend(**md_resp.headers)
+    resp.headers["Content-Type"] = md_resp.headers["Content-Type"]
     return resp
 
 
